@@ -21,6 +21,7 @@ from ..utils.auth import AuthManager
 from ..utils.config import Config
 from ..utils.colors import get_console, get_status_color, format_status_icon, print_success, print_error, print_warning, print_info
 from ..client.api_client import IvyBloomAPIClient
+from ..utils.printing import emit_json
 
 console = get_console()
 
@@ -126,7 +127,7 @@ def list(ctx, project_id, status, tool, limit, offset, created_after, created_be
             jobs_data = client.list_jobs(**filters)
         
         if format == 'json':
-            console.print(json.dumps(jobs_data, indent=2))
+            emit_json(jobs_data)
         elif format == 'yaml':
             import yaml
             console.print(yaml.dump(jobs_data, default_flow_style=False))
@@ -301,7 +302,7 @@ def status(ctx, job_id, follow, logs, format):
                 job_data = client.get_job_status(job_id, include_logs=logs)
                 
                 if format == 'json':
-                    console.print(json.dumps(job_data, indent=2))
+                    emit_json(job_data)
                 else:
                     status_panel = _create_status_panel(job_data)
                     console.print(status_panel)
@@ -366,13 +367,14 @@ def results(ctx, job_id, format, output):
         else:
             # Print to console
             if format == 'json':
-                console.print(json.dumps(results_data, indent=2))
+                emit_json(results_data)
             else:
                 console.print(results_data)
         
-        # Suggest download command for file artifacts
-        console.print(f"\n[dim]💡 To download result files (PDB, ZIP, etc.), use:[/dim]")
-        console.print(f"[dim]   ivybloom jobs download {job_id}[/dim]")
+        # Suggest download command only when not printing JSON to stdout
+        if format != 'json' and not output:
+            console.print(f"\n[dim]💡 To download result files (PDB, ZIP, etc.), use:[/dim]")
+            console.print(f"[dim]   ivybloom jobs download {job_id}[/dim]")
     
     except Exception as e:
         console.print(f"[red]❌ Error getting job results: {e}[/red]")
@@ -428,7 +430,7 @@ def download(ctx, job_id, artifact_type, output_dir, list_only, format):
         if list_only:
             # Just show available artifacts
             if format == 'json':
-                console.print(json.dumps(download_data, indent=2))
+                emit_json(download_data)
                 return
             
             # Table format
