@@ -2,11 +2,8 @@ from __future__ import annotations
 
 from typing import Optional, Dict, Any, List, Tuple
 import webbrowser
-import subprocess
 import json
 import math
-import csv
-import io
 
 from textual.app import App, ComposeResult
 from textual.widgets import Header, Footer, DataTable, Static, Input, LoadingIndicator, TabbedContent, TabPane
@@ -91,6 +88,9 @@ class IvyBloomTUI(App):
         self._structure_points: List[Tuple[float, float, float]] = []
         self._structure_angle: float = 0.0
         self._structure_timer = None
+        # Help toggle state
+        self._help_visible: bool = False
+        self._help_prev_renderable = None
 
         # Services
         self._runner = CLIRunner(self.config)
@@ -140,30 +140,19 @@ class IvyBloomTUI(App):
         self.jobs_table.add_columns("Job ID", "Tool", "Status", "Result")
         self.jobs_table.cursor_type = "row"
         self.jobs_table.focus()
-        # Welcome + optional project selection
+        # Welcome message
         try:
             user = self.auth_manager.get_current_user_id() if hasattr(self.auth_manager, 'get_current_user_id') else None
             welcome = f"Welcome, {user}!" if user else "Welcome!"
             if self.details_summary:
-                self.details_summary.update(f"[bold]{welcome}[/bold] Select a project to get started.\n[dim]Hint: Press '/' then choose 'Project: Pick'[/dim]")
-            if not self.initial_project_id:
-                projects = self._projects.list_projects()
-                if projects:
-                    self._picker_open = True
-                    self.push_screen(ProjectPicker(projects), self._on_project_picked)
-                    # Fallback timer: re-open picker if still no project selected
-                    try:
-                        self._project_pick_timer = self.set_timer(3, self._ensure_project_pick)
-                    except Exception:
-                        pass
+                self.details_summary.update(f"[bold]{welcome}[/bold] Initializing…")
         except Exception:
             pass
-        # If a project is already set, show splash and load jobs
-        if self.initial_project_id:
-            self._splash_opened = False  # type: ignore[attr-defined]
-            self._show_splash()
-            self.call_later(self._load_jobs)
-        # Auto refresh and connectivity
+        # Forced splash + boot sequence
+        self._splash_opened = False  # type: ignore[attr-defined]
+        self._show_splash()
+        self._start_boot_sequence()
+        # Auto refresh and connectivity (kicks in after boot)
         try:
             self.set_interval(self.refresh_interval_secs, lambda: self.call_later(self._load_jobs))
             self.set_interval(10, self._probe_connectivity)
@@ -188,20 +177,104 @@ class IvyBloomTUI(App):
         except Exception:
             pass
 
+    def _start_boot_sequence(self) -> None:
+        """Show splash for at least 5 seconds while connecting; then auth; then project pick; then load jobs."""
+        # Kick off an initial connectivity probe
+        try:
+            self._probe_connectivity()
+        except Exception:
+            pass
+        # Continue boot after minimum splash duration
+        try:
+            self.set_timer(5, self._continue_boot_sequence)
+        except Exception:
+            # If timers fail, continue immediately
+            self._continue_boot_sequence()
+
+    def _continue_boot_sequence(self) -> None:
+        # Require authentication first
+        try:
+            if not self.auth_manager.is_authenticated():
+                if self.details_summary:
+                    self.details_summary.update("Please authenticate to continue (browser|device|link|paste API key).")
+                self.push_screen(PromptScreen("Authenticate (browser|device|link|or paste API key)", placeholder="browser"), self._on_auth_chosen)
+                return
+        except Exception:
+            # If auth manager errors, still try to prompt
+            self.push_screen(PromptScreen("Authenticate (browser|device|link|or paste API key)", placeholder="browser"), self._on_auth_chosen)
+            return
+        # If authenticated, ensure project selection
+        self.call_later(self._ensure_project_then_load)
+
+    def _on_auth_chosen(self, choice: Optional[str]) -> None:
+        sel = (choice or "").strip()
+        if not sel:
+            # default to browser
+            sel = "browser"
+        try:
+            if sel.lower() in {"browser", "b"}:
+                text = self._run_cli_text(["auth", "login", "--browser"], timeout=600) or ""
+            elif sel.lower() in {"device", "d"}:
+                text = self._run_cli_text(["auth", "login", "--device"], timeout=600) or ""
+            elif sel.lower() in {"link", "l"}:
+                text = self._run_cli_text(["auth", "login", "--link"], timeout=600) or ""
+            else:
+                # Treat input as API key
+                text = self._run_cli_text(["auth", "login", "--api-key", sel], timeout=120) or ""
+            if self.details_summary:
+                self.details_summary.update(text or "Authentication flow completed.")
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Authentication failed: {e}[/red]")
+            # Re-prompt
+            self.push_screen(PromptScreen("Authenticate (browser|device|link|or paste API key)", placeholder="browser"), self._on_auth_chosen)
+            return
+        # After auth, proceed to project selection
+        self.call_later(self._ensure_project_then_load)
+
+    def _ensure_project_then_load(self) -> None:
+        # If no project chosen, open picker; otherwise load jobs and hide splash once loaded
+        if not self.initial_project_id:
+            try:
+                projects = self._projects.list_projects()
+                if projects:
+                    self._picker_open = True
+                    self.push_screen(ProjectPicker(projects), self._on_project_picked)
+                    if self.details_summary:
+                        self.details_summary.update("Select a project to continue…")
+                    return
+                else:
+                    if self.details_summary:
+                        self.details_summary.update("No projects available. Create one in the web app.")
+            except Exception as e:
+                if self.details_summary:
+                    self.details_summary.update(f"[red]Failed to load projects: {e}[/red]")
+                # Retry shortly
+                try:
+                    self.set_timer(3, self._ensure_project_then_load)
+                except Exception:
+                    pass
+                return
+        # If we have a project, load jobs
+        self.call_later(self._load_jobs)
+
     # ------------------ Command Palette ------------------
     def action_open_palette(self) -> None:
         commands = [
-            ("list_tools", "Tools: List", "Show available tools in a table"),
-            ("tools_info", "Tools: Info", "Show detailed info for a tool"),
-            ("tools_schema", "Tools: Schema", "Show parameter schema for a tool"),
-            ("tools_completions", "Tools: Completions", "Show enum choices for a tool"),
+            ("list_tools", "Tools: List", "Show tools (choose format/verbosity)"),
+            ("tools_info", "Tools: Info", "Show detailed info for a tool (choose format)"),
+            ("tools_schema", "Tools: Schema", "Show parameter schema for a tool (choose format)"),
+            ("tools_completions", "Tools: Completions", "Show enum choices for a tool (choose format)"),
             ("jobs_list", "Jobs: List", "List jobs with optional filters"),
             ("jobs_status", "Jobs: Status", "Show job status (optionally follow)"),
             ("jobs_results", "Jobs: Results", "Fetch job results (JSON)"),
             ("jobs_download", "Jobs: Download", "List/download job artifacts"),
             ("jobs_cancel", "Jobs: Cancel", "Cancel a running job"),
             ("projects_list", "Projects: List", "List projects"),
+            ("projects_info", "Projects: Info", "Show project info"),
+            ("projects_jobs", "Projects: Jobs", "List jobs for a project"),
             ("account_info", "Account: Info", "Show account info"),
+            ("account_usage", "Account: Usage", "Show usage (choose period/tool)"),
             ("run_tool", "Run: Tool", "Run a tool with key=value params"),
             ("workflows_run", "Workflows: Run", "Run a workflow file"),
             ("refresh", "Refresh", "Reload jobs"),
@@ -215,6 +288,7 @@ class IvyBloomTUI(App):
             ("run_custom", "Run CLI: Custom", "Run arbitrary ivybloom args"),
             ("artifacts_list", "Artifacts: List", "List artifacts for selected job"),
             ("artifact_preview", "Artifacts: Preview", "Preview JSON/CSV for selected job"),
+            ("artifact_open_primary", "Artifacts: Open Primary", "Open primary (or best) artifact externally"),
             ("protein_view_ascii", "Protein: View ASCII", "Load and rotate ASCII protein (PDB)"),
             ("protein_stop_ascii", "Protein: Stop ASCII", "Stop protein ASCII view"),
             ("pick_project", "Project: Pick", "Select a project to focus"),
@@ -225,17 +299,41 @@ class IvyBloomTUI(App):
         if not result:
             return
         if result == "list_tools":
-            self.call_later(self._show_tools)
+            # Prompt for options: format, verbose, schemas
+            def _after_fmt(fmt: Optional[str]):
+                def _after_verbose(verbose: Optional[str]):
+                    def _after_schemas(schemas: Optional[str]):
+                        self.call_later(lambda: self._cmd_tools_list(fmt or "table", (verbose or "no").lower() in {"yes","y","true"}, (schemas or "no").lower() in {"yes","y","true"}))
+                    self.push_screen(PromptScreen("Embed schemas? (yes/no)", placeholder="no"), _after_schemas)
+                self.push_screen(PromptScreen("Verbose? (yes/no)", placeholder="no"), _after_verbose)
+            self.push_screen(PromptScreen("Format (table|json)", placeholder="table"), _after_fmt)
         elif result == "tools_info":
-            self.push_screen(PromptScreen("Tool name (e.g., esmfold)"), lambda val: self._cmd_tools_info(val))
+            def _after_tool(tool: Optional[str]):
+                if not tool:
+                    return
+                self.push_screen(PromptScreen("Format (table|json)", placeholder="table"), lambda fmt: self._cmd_tools_info(tool, fmt or "table"))
+            self.push_screen(PromptScreen("Tool name (e.g., esmfold)"), _after_tool)
         elif result == "tools_schema":
-            self.push_screen(PromptScreen("Tool name for schema"), lambda val: self._cmd_tools_schema(val))
+            def _after_tool_schema(tool: Optional[str]):
+                if not tool:
+                    return
+                self.push_screen(PromptScreen("Format (table|json)", placeholder="table"), lambda fmt: self._cmd_tools_schema(tool, fmt or "table"))
+            self.push_screen(PromptScreen("Tool name for schema"), _after_tool_schema)
         elif result == "tools_completions":
-            self.push_screen(PromptScreen("Tool name for completions"), lambda tool: self._cmd_tools_completions(tool))
+            def _after_tool_comp(tool: Optional[str]):
+                if not tool:
+                    return
+                self.push_screen(PromptScreen("Format (table|json)", placeholder="table"), lambda fmt: self._cmd_tools_completions(tool, fmt or "table"))
+            self.push_screen(PromptScreen("Tool name for completions"), _after_tool_comp)
         elif result == "jobs_list":
-            self.push_screen(PromptScreen("Extra filters (e.g. --status running --tool esmfold)", placeholder="optional"), lambda extra: self._cmd_jobs_list(extra))
+            self.push_screen(FiltersScreen(), lambda filters: self._cmd_jobs_list_with_filters(filters))
         elif result == "jobs_status":
-            self.push_screen(PromptScreen("Job ID (add --follow or --logs in next step)"), lambda job_id: self._cmd_jobs_status(job_id))
+            # Ask for job id, then optional flags
+            def _after_job_id(job_id: Optional[str]) -> None:
+                if not job_id:
+                    return
+                self.push_screen(PromptScreen("Extra flags (e.g., --follow --logs)", placeholder="optional"), lambda flags: self._cmd_jobs_status(job_id, flags))
+            self.push_screen(PromptScreen("Job ID (then choose flags)"), _after_job_id)
         elif result == "jobs_results":
             self.push_screen(PromptScreen("Job ID for results"), lambda job_id: self._cmd_jobs_results(job_id))
         elif result == "jobs_download":
@@ -244,12 +342,22 @@ class IvyBloomTUI(App):
             self.push_screen(PromptScreen("Job ID to cancel"), lambda job_id: self._cmd_jobs_cancel(job_id))
         elif result == "projects_list":
             self.call_later(self._cmd_projects_list)
+        elif result == "projects_info":
+            self.push_screen(PromptScreen("Project ID"), lambda pid: self._cmd_projects_info(pid))
+        elif result == "projects_jobs":
+            self.push_screen(PromptScreen("Project ID"), lambda pid: self._cmd_projects_jobs(pid))
         elif result == "account_info":
             self.call_later(self._cmd_account_info)
+        elif result == "account_usage":
+            def _after_tool(val_tool: Optional[str]):
+                self.push_screen(PromptScreen("Period (month|30days|all)", placeholder="month"), lambda period: self._cmd_account_usage(val_tool, period or "month"))
+            self.push_screen(PromptScreen("Filter by tool (optional)"), _after_tool)
         elif result == "artifacts_list":
             self.call_later(self._cmd_artifacts_list)
         elif result == "artifact_preview":
             self.push_screen(PromptScreen("Artifact type or filename (optional)", placeholder="optional"), lambda sel: self._cmd_artifact_preview(sel))
+        elif result == "artifact_open_primary":
+            self.call_later(self._cmd_artifact_open_primary)
         elif result == "protein_view_ascii":
             self._cmd_protein_view_ascii()
         elif result == "protein_stop_ascii":
@@ -272,45 +380,62 @@ class IvyBloomTUI(App):
             # No filters currently; noop
             pass
         elif result == "quick_status_running":
-            # No filters currently; noop
-            pass
+            self._cmd_jobs_list_with_filters({"status": "running"})
         elif result == "quick_status_completed":
-            # No filters currently; noop
-            pass
+            self._cmd_jobs_list_with_filters({"status": "completed"})
         elif result == "open_external":
             self.action_open_external()
         elif result == "toggle_help":
             self.action_toggle_help()
 
-    async def _show_tools(self) -> None:
+    async def _cmd_tools_list(self, fmt: str, verbose: bool, schemas: bool) -> None:
         try:
-            # Thin wrapper: call CLI and render JSON
-            tools_json = self._run_cli_json(["tools", "list", "--format", "json"]) or []
-            # tools_json may be a list of dicts or names
-            table = Table(title="Available Tools", show_lines=False, show_header=True, header_style=f"bold {EARTH_TONES['sage_dark']}", box=box.SIMPLE_HEAVY)
-            table.add_column("ID", style="cyan", no_wrap=True)
-            table.add_column("Name", style="white")
-            table.add_column("Description", style="white")
-            if isinstance(tools_json, list):
-                for item in tools_json:
-                    if isinstance(item, dict):
-                        table.add_row(
-                            str(item.get("id") or item.get("name") or ""),
-                            str(item.get("name") or item.get("id") or ""),
-                            str(item.get("description") or ""),
-                        )
-                    else:
-                        name_val = str(item)
-                        table.add_row(name_val, name_val, "")
-            if self.details_summary:
-                self.details_summary.update(table)
+            args = ["tools", "list", "--format", fmt or "table"]
+            if verbose:
+                args.append("--verbose")
+            if schemas:
+                args.append("--format-json-with-schemas")
+            if (fmt or "table").lower() == "json":
+                data = self._run_cli_json(args) or []
+                pretty = json.dumps(data, indent=2)
+                if self.details_params:
+                    self.details_params.update(pretty)
+            else:
+                # Table: if JSON list provided, render custom table; else reuse CLI text
+                try:
+                    tools_json = self._run_cli_json(["tools", "list", "--format", "json"] + (["--verbose"] if verbose else [])) or []
+                    table = Table(title="Available Tools", show_lines=False, show_header=True, header_style=f"bold {EARTH_TONES['sage_dark']}", box=box.SIMPLE_HEAVY)
+                    table.add_column("ID", style="cyan", no_wrap=True)
+                    table.add_column("Name", style="white")
+                    table.add_column("Description", style="white")
+                    if isinstance(tools_json, list):
+                        for item in tools_json:
+                            if isinstance(item, dict):
+                                table.add_row(
+                                    str(item.get("id") or item.get("name") or ""),
+                                    str(item.get("name") or item.get("id") or ""),
+                                    str(item.get("description") or ""),
+                                )
+                            else:
+                                name_val = str(item)
+                                table.add_row(name_val, name_val, "")
+                    if self.details_summary:
+                        self.details_summary.update(table)
+                except Exception:
+                    text = self._run_cli_text(args) or ""
+                    if self.details_summary:
+                        self.details_summary.update(text)
+            self._last_error = None
         except Exception as e:
+            self._last_error = str(e)
             if self.details_summary:
                 self.details_summary.update(f"[red]Failed to load tools: {e}[/red]")
+        finally:
+            self._update_status_bar()
 
     def _apply_filter(self, jobs: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
         # Filters disabled for now; keep placeholder for future
-            return jobs
+        return jobs
 
     async def _load_jobs(self) -> None:
         self.jobs_offset = 0
@@ -426,7 +551,31 @@ class IvyBloomTUI(App):
             self._cmd_run_custom(args_line)
 
     def action_toggle_help(self) -> None:
-            pass
+        if not self.details_summary:
+            return
+        if not self._help_visible:
+            # Save previous renderable and show shortcuts
+            self._help_prev_renderable = self.details_summary.renderable
+            help_text = "\n".join([
+                "[b]Shortcuts[/b]",
+                " r  – Refresh",
+                " /  – Open command palette",
+                " f  – Focus command input",
+                " o  – Open artifact externally",
+                " ?  – Toggle help",
+                " q  – Quit",
+            ])
+            self.details_summary.update(help_text)
+            self._help_visible = True
+        else:
+            # Restore previous content
+            try:
+                if self._help_prev_renderable is not None:
+                    self.details_summary.update(self._help_prev_renderable)
+            except Exception:
+                self.details_summary.update("")
+            finally:
+                self._help_visible = False
 
     def action_open_external(self) -> None:
         job = self.selected_job
@@ -470,25 +619,8 @@ class IvyBloomTUI(App):
 
     # ------------------ CLI wrapper helper ------------------
     def _run_cli_json(self, args: List[str], timeout: int = 30) -> Any:
-        """Run ivybloom CLI with provided args and parse JSON output.
-        Prepends --config-file to ensure same context as running CLI.
-        Raises on non-zero exit or invalid JSON.
-        """
-        cmd: List[str] = [
-            "ivybloom",
-            "--config-file",
-            str(self.config.config_path),
-        ] + args
-        result = subprocess.run(cmd, capture_output=True, text=True, timeout=timeout)
-        if result.returncode != 0:
-            raise RuntimeError(result.stdout.strip() + "\n" + result.stderr.strip())
-        output = result.stdout.strip()
-        if not output:
-            return None
-        try:
-            return json.loads(output)
-        except json.JSONDecodeError:
-            raise RuntimeError(f"Invalid JSON from CLI: {output[:200]}...")
+        """Delegate to CLIRunner for JSON output."""
+        return self._runner.run_cli_json(args, timeout=timeout)
         
     def _probe_connectivity(self) -> None:
         try:
@@ -508,15 +640,8 @@ class IvyBloomTUI(App):
         self.status_bar.update(status)
 
     def _run_cli_text(self, args: List[str], timeout: int = 60, input_text: Optional[str] = None) -> str:
-        cmd: List[str] = [
-            "ivybloom",
-            "--config-file",
-            str(self.config.config_path),
-        ] + args
-        result = subprocess.run(cmd, input=input_text, capture_output=True, text=True, timeout=timeout)
-        if result.returncode != 0:
-            raise RuntimeError(result.stdout.strip() + "\n" + result.stderr.strip())
-        return result.stdout
+        """Delegate to CLIRunner for text output."""
+        return self._runner.run_cli_text(args, timeout=timeout, input_text=input_text)
 
     # ------------------ Command handlers (thin wrappers) ------------------
     async def _cmd_projects_list(self) -> None:
@@ -528,6 +653,28 @@ class IvyBloomTUI(App):
             if self.details_summary:
                 self.details_summary.update(f"[red]Projects list failed: {e}[/red]")
 
+    def _cmd_projects_info(self, project_id: Optional[str]) -> None:
+        if not project_id:
+            return
+        try:
+            text = self._run_cli_text(["projects", "info", project_id, "--format", "table"]) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Project info failed: {e}[/red]")
+
+    def _cmd_projects_jobs(self, project_id: Optional[str]) -> None:
+        if not project_id:
+            return
+        try:
+            text = self._run_cli_text(["projects", "jobs", project_id, "--format", "table"]) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Project jobs failed: {e}[/red]")
+
     async def _cmd_account_info(self) -> None:
         try:
             text = self._run_cli_text(["account", "info"]) or ""
@@ -537,44 +684,77 @@ class IvyBloomTUI(App):
             if self.details_summary:
                 self.details_summary.update(f"[red]Account info failed: {e}[/red]")
 
-    def _cmd_tools_info(self, tool: Optional[str]) -> None:
+    def _cmd_account_usage(self, tool: Optional[str], period: str) -> None:
+        try:
+            args = ["account", "usage", "--format", "table"]
+            if tool:
+                args += ["--tool", tool]
+            if period:
+                args += ["--period", period]
+            text = self._run_cli_text(args) or ""
+            if self.details_summary:
+                self.details_summary.update(text)
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Account usage failed: {e}[/red]")
+
+    def _cmd_tools_info(self, tool: Optional[str], fmt: str = "table") -> None:
         if not tool:
             return
         try:
-            text = self._run_cli_text(["tools", "info", tool, "--format", "table"]) or ""
-            if self.details_summary:
-                self.details_summary.update(text)
+            if fmt == "json":
+                data = self._run_cli_json(["tools", "info", tool, "--format", "json"]) or {}
+                pretty = json.dumps(data, indent=2)
+                if self.details_params:
+                    self.details_params.update(pretty)
+            else:
+                text = self._run_cli_text(["tools", "info", tool, "--format", "table"]) or ""
+                if self.details_summary:
+                    self.details_summary.update(text)
         except Exception as e:
             if self.details_summary:
                 self.details_summary.update(f"[red]Tool info failed: {e}[/red]")
 
-    def _cmd_tools_schema(self, tool: Optional[str]) -> None:
+    def _cmd_tools_schema(self, tool: Optional[str], fmt: str = "table") -> None:
         if not tool:
             return
         try:
-            text = self._run_cli_text(["tools", "schema", tool, "--format", "table"]) or ""
-            if self.details_summary:
-                self.details_summary.update(text)
+            if fmt == "json":
+                data = self._run_cli_json(["tools", "schema", tool, "--format", "json"]) or {}
+                pretty = json.dumps(data, indent=2)
+                if self.details_params:
+                    self.details_params.update(pretty)
+            else:
+                text = self._run_cli_text(["tools", "schema", tool, "--format", "table"]) or ""
+                if self.details_summary:
+                    self.details_summary.update(text)
         except Exception as e:
             if self.details_summary:
                 self.details_summary.update(f"[red]Tool schema failed: {e}[/red]")
 
-    def _cmd_tools_completions(self, tool: Optional[str]) -> None:
+    def _cmd_tools_completions(self, tool: Optional[str], fmt: str = "table") -> None:
         if not tool:
             return
         try:
-            text = self._run_cli_text(["tools", "completions", tool, "--format", "table"]) or ""
-            if self.details_summary:
-                self.details_summary.update(text)
+            if fmt == "json":
+                data = self._run_cli_json(["tools", "completions", tool, "--format", "json"]) or {}
+                pretty = json.dumps(data, indent=2)
+                if self.details_params:
+                    self.details_params.update(pretty)
+            else:
+                text = self._run_cli_text(["tools", "completions", tool, "--format", "table"]) or ""
+                if self.details_summary:
+                    self.details_summary.update(text)
         except Exception as e:
             if self.details_summary:
                 self.details_summary.update(f"[red]Tool completions failed: {e}[/red]")
 
-    def _cmd_jobs_list(self, extra_args: Optional[str]) -> None:
-        import shlex
+    def _cmd_jobs_list_with_filters(self, filters: Optional[Dict[str, str]]) -> None:
         args = ["jobs", "list", "--format", "json"]
-        if extra_args:
-            args += shlex.split(extra_args)
+        if filters:
+            for k, v in filters.items():
+                if v:
+                    args += [f"--{k}", str(v)]
         try:
             jobs = self._run_cli_json(args) or []
             if not isinstance(jobs, list):
@@ -594,13 +774,24 @@ class IvyBloomTUI(App):
             if self.details_summary:
                 self.details_summary.update(f"[red]Jobs list failed: {e}[/red]")
 
-    def _cmd_jobs_status(self, job_id: Optional[str]) -> None:
+    def _cmd_jobs_status(self, job_id: Optional[str], extra_flags: Optional[str]) -> None:
         if not job_id:
             return
         try:
-            text = self._run_cli_text(["jobs", "status", job_id, "--format", "table"]) or ""
-            if self.details_summary:
-                self.details_summary.update(text)
+            import shlex
+            args = ["jobs", "status", job_id, "--format", "table"]
+            if extra_flags:
+                args += shlex.split(extra_flags)
+            # If follow requested, stream lines into Summary
+            follow = any(flag in args for flag in ["--follow", "-f"]) 
+            if follow and self.details_summary:
+                self.details_summary.update("[dim]Following job... press Ctrl+C in terminal to stop.[/dim]")
+                for line in self._runner.run_cli_stream(args):
+                    self.details_summary.update(line)
+            else:
+                text = self._run_cli_text(args, timeout=600) or ""
+                if self.details_summary:
+                    self.details_summary.update(text)
         except Exception as e:
             if self.details_summary:
                 self.details_summary.update(f"[red]Jobs status failed: {e}[/red]")
@@ -609,9 +800,34 @@ class IvyBloomTUI(App):
         if not job_id:
             return
         try:
-            text = self._run_cli_text(["jobs", "results", job_id, "--format", "json"]) or ""
-            if self.details_summary:
-                self.details_summary.update(text)
+            data = self._run_cli_json(["jobs", "results", job_id, "--format", "json"]) or {}
+            # Render as table if list-of-dicts
+            table = None
+            if isinstance(data, list) and data and isinstance(data[0], dict):
+                cols = list(data[0].keys())[:20]
+                table = Table(title="Job Results")
+                for c in cols:
+                    table.add_column(str(c))
+                for row in data[:200]:
+                    table.add_row(*[str(row.get(c, ""))[:120] for c in cols])
+            elif isinstance(data, dict):
+                # If "results" key exists and is list-of-dicts, tabularize that
+                results = data.get("results")
+                if isinstance(results, list) and results and isinstance(results[0], dict):
+                    cols = list(results[0].keys())[:20]
+                    table = Table(title="Job Results")
+                    for c in cols:
+                        table.add_column(str(c))
+                    for row in results[:200]:
+                        table.add_row(*[str(row.get(c, ""))[:120] for c in cols])
+            if table is not None:
+                if self.details_summary:
+                    self.details_summary.update(table)
+            else:
+                # Fallback to pretty JSON string
+                pretty = json.dumps(data, indent=2)
+                if self.details_summary:
+                    self.details_summary.update(pretty)
         except Exception as e:
             if self.details_summary:
                 self.details_summary.update(f"[red]Jobs results failed: {e}[/red]")
@@ -800,11 +1016,46 @@ class IvyBloomTUI(App):
                 return
             # Fallback
             if self.details_artifacts:
-                self.details_artifacts.update(f"Unsupported content type: {content_type or 'unknown'}. Use Open/Download.")
+                self.details_artifacts.update("Unsupported inline preview. Use 'Artifacts: Open Primary' or 'Jobs: Download'.")
         except Exception as e:
             if self.details_artifacts:
                 self.details_artifacts.update(f"[red]Artifact preview failed: {e}[/red]")
 
+    def _cmd_artifact_open_primary(self) -> None:
+        job = self.selected_job
+        if not job:
+            if self.details_summary:
+                self.details_summary.update("No job selected")
+            return
+        job_id = str(job.get("job_id") or job.get("id") or "").strip()
+        if not job_id:
+            if self.details_summary:
+                self.details_summary.update("Invalid job id")
+            return
+        try:
+            data = self._run_cli_json(["jobs", "download", job_id, "--list-only", "--format", "json"]) or {}
+            artifacts = data.get("artifacts") if isinstance(data, dict) else []
+            url = None
+            if isinstance(artifacts, list):
+                chosen = next((a for a in artifacts if isinstance(a, dict) and a.get("primary")), None)
+                if not chosen:
+                    for pref in ("pdb", "sdf", "zip", "primary"):
+                        chosen = next((a for a in artifacts if isinstance(a, dict) and pref in str(a.get("artifact_type") or a.get("type") or "").lower()), None)
+                        if chosen:
+                            break
+                if chosen:
+                    url = chosen.get("presigned_url") or chosen.get("url")
+            if url:
+                webbrowser.open(url)
+                if self.details_summary:
+                    self.details_summary.update("Opening primary artifact in browser...")
+            else:
+                if self.details_summary:
+                    self.details_summary.update("No suitable artifact URL found.")
+        except Exception as e:
+            if self.details_summary:
+                self.details_summary.update(f"[red]Open primary failed: {e}[/red]")
+
     def _cmd_protein_view_ascii(self) -> None:
         job = self.selected_job
         if not job:
@@ -942,6 +1193,12 @@ class CommandPalette(ModalScreen[Optional[str]]):
         self._refresh_list()
         if self.query_input:
             self.query_input.focus()
+        # Ensure the first item is highlighted for immediate arrow/enter usage
+        if self.list_view and len(self.list_view.children) > 0:
+            try:
+                self.list_view.index = 0  # type: ignore[attr-defined]
+            except Exception:
+                pass
 
     def _refresh_list(self) -> None:
         if not self.list_view:
@@ -949,6 +1206,12 @@ class CommandPalette(ModalScreen[Optional[str]]):
         self.list_view.clear()
         for cmd_id, name, desc in self._filtered:
             self.list_view.append(ListItem(Static(f"[b]{name}[/b]\n[dim]{desc}[/dim]")))
+        # Keep cursor at top after refresh so Enter selects the first item
+        try:
+            if len(self._filtered) > 0 and self.list_view:
+                self.list_view.index = 0  # type: ignore[attr-defined]
+        except Exception:
+            pass
 
     def on_input_changed(self, event: Input.Changed) -> None:  # type: ignore[override]
         if event.input is not self.query_input:
@@ -970,8 +1233,39 @@ class CommandPalette(ModalScreen[Optional[str]]):
             self.dismiss(None)
 
     def on_key(self, event) -> None:  # type: ignore[override]
+        # Esc closes the palette
         if event.key == "escape":
             self.dismiss(None)
+            return
+        # Arrow keys navigate the list even when focus is in the query input
+        if event.key in ("down", "up") and self.list_view:
+            try:
+                self.list_view.focus()
+                if event.key == "down":
+                    self.list_view.action_cursor_down()  # type: ignore[attr-defined]
+                else:
+                    self.list_view.action_cursor_up()  # type: ignore[attr-defined]
+                event.stop()
+            except Exception:
+                pass
+            return
+        # Enter selects the current item
+        if event.key == "enter":
+            try:
+                if self.list_view and len(self._filtered) > 0:
+                    # If focus is on list, trigger selection; otherwise, pick current index (default 0)
+                    if self.list_view.has_focus:
+                        self.list_view.action_select_cursor()  # type: ignore[attr-defined]
+                    else:
+                        idx = getattr(self.list_view, "index", 0)  # type: ignore[attr-defined]
+                        idx = 0 if idx is None else idx
+                        if 0 <= idx < len(self._filtered):
+                            self.dismiss(self._filtered[idx][0])
+                        else:
+                            self.dismiss(None)
+                    event.stop()
+            except Exception:
+                pass
 
 
 class PromptScreen(ModalScreen[Optional[str]]):
@@ -1000,6 +1294,56 @@ class PromptScreen(ModalScreen[Optional[str]]):
             self.dismiss(None)
 
 
+class FiltersScreen(ModalScreen[Optional[Dict[str, str]]]):
+    def __init__(self) -> None:
+        super().__init__()
+        self.inputs: Dict[str, Input] = {}
+
+    def compose(self) -> ComposeResult:
+        with Vertical():
+            yield Static("Jobs Filters (leave blank to skip)")
+            for label, key in [
+                ("Status", "status"),
+                ("Tool", "tool"),
+                ("Project ID", "project-id"),
+                ("Created After (ISO)", "created-after"),
+                ("Created Before (ISO)", "created-before"),
+                ("Sort By (created_at|status|job_type)", "sort-by"),
+                ("Sort Order (asc|desc)", "sort-order"),
+            ]:
+                yield Static(label)
+                inp = Input()
+                self.inputs[key] = inp
+                yield inp
+            yield Static("Limit (default 50)")
+            limit_inp = Input()
+            self.inputs["limit"] = limit_inp
+            yield limit_inp
+            yield Static("Offset (default 0)")
+            offset_inp = Input()
+            self.inputs["offset"] = offset_inp
+            yield offset_inp
+            yield Static("Press Enter to apply; Esc to cancel", classes="muted")
+
+    def on_mount(self) -> None:
+        # Focus first field
+        if self.inputs:
+            first = next(iter(self.inputs.values()))
+            first.focus()
+
+    def on_input_submitted(self, event: Input.Submitted) -> None:  # type: ignore[override]
+        # When any input submits, collect all values and dismiss
+        values: Dict[str, str] = {}
+        for k, inp in self.inputs.items():
+            val = (inp.value or "").strip()
+            if val:
+                values[k] = val
+        self.dismiss(values or None)
+
+    def on_key(self, event) -> None:  # type: ignore[override]
+        if event.key == "escape":
+            self.dismiss(None)
+
 class SplashScreen(ModalScreen[None]):
     def __init__(self, title: str = "IvyBloom", subtitle: str = "Loading…"):
         super().__init__()
